proc start_step { step } {
  set stopFile ".stop.rst"
  if {[file isfile .stop.rst]} {
    puts ""
    puts "*** Halting run - EA reset detected ***"
    puts ""
    puts ""
    return -code error
  }
  set beginFile ".$step.begin.rst"
  set platform "$::tcl_platform(platform)"
  set user "$::tcl_platform(user)"
  set pid [pid]
  set host ""
  if { [string equal $platform unix] } {
    if { [info exist ::env(HOSTNAME)] } {
      set host $::env(HOSTNAME)
    }
  } else {
    if { [info exist ::env(COMPUTERNAME)] } {
      set host $::env(COMPUTERNAME)
    }
  }
  set ch [open $beginFile w]
  puts $ch "<?xml version=\"1.0\"?>"
  puts $ch "<ProcessHandle Version=\"1\" Minor=\"0\">"
  puts $ch "    <Process Command=\".planAhead.\" Owner=\"$user\" Host=\"$host\" Pid=\"$pid\">"
  puts $ch "    </Process>"
  puts $ch "</ProcessHandle>"
  close $ch
}

proc end_step { step } {
  set endFile ".$step.end.rst"
  set ch [open $endFile w]
  close $ch
}

proc step_failed { step } {
  set endFile ".$step.error.rst"
  set ch [open $endFile w]
  close $ch
}

set_msg_config -id {HDL 9-1061} -limit 100000
set_msg_config -id {HDL 9-1654} -limit 100000

start_step init_design
set rc [catch {
  create_msg_db init_design.pb
  set_property design_mode GateLvl [current_fileset]
  set_param project.singleFileAddWarning.threshold 0
  set_property webtalk.parent_dir C:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.cache/wt [current_project]
  set_property parent.project_path C:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.xpr [current_project]
  set_property ip_repo_paths c:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.cache/ip [current_project]
  set_property ip_output_repo c:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.cache/ip [current_project]
  add_files -quiet C:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.runs/synth_1/nexys4_vga_minimal.dcp
  add_files -quiet C:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/sources_1/ip/xadc_wiz_0/xadc_wiz_0.dcp
  set_property netlist_only true [get_files C:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/sources_1/ip/xadc_wiz_0/xadc_wiz_0.dcp]
  read_xdc -mode out_of_context -ref xadc_wiz_0 -cells U0 c:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/sources_1/ip/xadc_wiz_0/xadc_wiz_0_ooc.xdc
  set_property processing_order EARLY [get_files c:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/sources_1/ip/xadc_wiz_0/xadc_wiz_0_ooc.xdc]
  read_xdc -ref xadc_wiz_0 -cells U0 c:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/sources_1/ip/xadc_wiz_0/xadc_wiz_0.xdc
  set_property processing_order EARLY [get_files c:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/sources_1/ip/xadc_wiz_0/xadc_wiz_0.xdc]
  read_xdc C:/Users/LocalAdmin/Documents/nexys4_vga_minimal/nexys4_vga_minimal.srcs/constrs_1/Nexys4_Master.xdc
  link_design -top nexys4_vga_minimal -part xc7a100tcsg324-1
  write_hwdef -file nexys4_vga_minimal.hwdef
  close_msg_db -file init_design.pb
} RESULT]
if {$rc} {
  step_failed init_design
  return -code error $RESULT
} else {
  end_step init_design
}

start_step opt_design
set rc [catch {
  create_msg_db opt_design.pb
  opt_design 
  write_checkpoint -force nexys4_vga_minimal_opt.dcp
  report_drc -file nexys4_vga_minimal_drc_opted.rpt
  close_msg_db -file opt_design.pb
} RESULT]
if {$rc} {
  step_failed opt_design
  return -code error $RESULT
} else {
  end_step opt_design
}

start_step place_design
set rc [catch {
  create_msg_db place_design.pb
  implement_debug_core 
  place_design 
  write_checkpoint -force nexys4_vga_minimal_placed.dcp
  report_io -file nexys4_vga_minimal_io_placed.rpt
  report_utilization -file nexys4_vga_minimal_utilization_placed.rpt -pb nexys4_vga_minimal_utilization_placed.pb
  report_control_sets -verbose -file nexys4_vga_minimal_control_sets_placed.rpt
  close_msg_db -file place_design.pb
} RESULT]
if {$rc} {
  step_failed place_design
  return -code error $RESULT
} else {
  end_step place_design
}

start_step route_design
set rc [catch {
  create_msg_db route_design.pb
  route_design 
  write_checkpoint -force nexys4_vga_minimal_routed.dcp
  report_drc -file nexys4_vga_minimal_drc_routed.rpt -pb nexys4_vga_minimal_drc_routed.pb
  report_timing_summary -warn_on_violation -max_paths 10 -file nexys4_vga_minimal_timing_summary_routed.rpt -rpx nexys4_vga_minimal_timing_summary_routed.rpx
  report_power -file nexys4_vga_minimal_power_routed.rpt -pb nexys4_vga_minimal_power_summary_routed.pb -rpx nexys4_vga_minimal_power_routed.rpx
  report_route_status -file nexys4_vga_minimal_route_status.rpt -pb nexys4_vga_minimal_route_status.pb
  report_clock_utilization -file nexys4_vga_minimal_clock_utilization_routed.rpt
  close_msg_db -file route_design.pb
} RESULT]
if {$rc} {
  step_failed route_design
  return -code error $RESULT
} else {
  end_step route_design
}

