library ieee;
use ieee.std_logic_1164.all;
use IEEE.numeric_std.all;

entity nexys4_vga_minimal is Port(
	xadc_p		   : in std_logic;
    xadc_n         : in std_logic;
    xadc_vauxp15    : in std_logic;
    xadc_vauxn15    : in std_logic;
	clk : in std_logic;
    vgaRed, vgaBlue, vgaGreen : out std_logic_vector(3 downto 0);
    Hsync, Vsync: out std_logic);
end nexys4_vga_minimal;

architecture Behavioral of nexys4_vga_minimal is

component xadc_wiz_0 is port(
        daddr_in        : in  STD_LOGIC_VECTOR (6 downto 0);     -- Address bus for the dynamic reconfiguration port
        den_in          : in  STD_LOGIC;                         -- Enable Signal for the dynamic reconfiguration port
        di_in           : in  STD_LOGIC_VECTOR (15 downto 0);    -- Input data bus for the dynamic reconfiguration port
        dwe_in          : in  STD_LOGIC;                         -- Write Enable for the dynamic reconfiguration port
        do_out          : out  STD_LOGIC_VECTOR (15 downto 0);   -- Output data bus for dynamic reconfiguration port
        drdy_out        : out  STD_LOGIC;                        -- Data ready signal for the dynamic reconfiguration port
        dclk_in         : in  STD_LOGIC;                         -- Clock input for the dynamic reconfiguration port
        reset_in        : in  STD_LOGIC;                         -- Reset signal for the System Monitor control logic
        vauxp15          : in  STD_LOGIC;                         -- Auxiliary Channel 3
        vauxn15          : in  STD_LOGIC;
        busy_out        : out  STD_LOGIC;                        -- ADC Busy signal
        channel_out     : out  STD_LOGIC_VECTOR (4 downto 0);    -- Channel Selection Outputs
        eoc_out         : out  STD_LOGIC;                        -- End of Conversion Signal
        eos_out         : out  STD_LOGIC;                        -- End of Sequence Signal
        alarm_out       : out STD_LOGIC;                         -- OR'ed output of all the Alarms
        vp_in           : in  STD_LOGIC;                         -- Dedicated Analog Input Pair
        vn_in           : in  STD_LOGIC);
end component;

component clk_wiz_0 is port(
	clk_in : in std_logic;
	clk_out : out std_logic);
end component;

component vga_640 is port(
	clk_vga: in std_logic;
	horizontal_counter : out std_logic_vector (9 downto 0);
	vertical_counter   : out std_logic_vector (9 downto 0);
    hs_out   : out std_logic;
    vs_out   : out std_logic;
    frame_out: out std_logic
    );
end component;

signal clk25, vga_rect, vga_visible_v, vga_visible_h, frame: std_logic:='0';
signal hc_v, vc_v: std_logic_vector (9 downto 0):=(others => '0');
signal screen_h: integer range 0 to 1023:=0;
signal screen_v: integer range 0 to 511:=0;
signal int_move: integer range 0 to 1024:=0;
signal bool_move: std_logic:='0';

signal drdy_xadc: std_logic:='0';
signal eoc_xadc: std_logic:='0';
signal do_xadc: std_logic_vector(15 downto 0):=(others => '0'); 
signal value: std_logic_vector(12 downto 0):=(others => '0');

begin

pll0 : clk_wiz_0 port map(
	clk_in => clk,
	clk_out => clk25);
	
vga0 : vga_640 port map(
    clk_vga => clk25,
    horizontal_counter => hc_v,
    vertical_counter => vc_v,
    hs_out => Hsync,
    vs_out => Vsync,
    frame_out => frame);
    
xadc : xadc_wiz_0 port map(
        daddr_in    => "0011111", -- 19,
        den_in        => eoc_xadc,
        di_in        => (others => '0'),
        dwe_in        => '0',
        do_out        => do_xadc, -- Daten
        drdy_out    => drdy_xadc, -- wird verwendet um Daten zu erfassen
        dclk_in        => clk25,
        reset_in     => '0',
        vauxp15        => xadc_vauxp15,
        vauxn15        => xadc_vauxn15,
        busy_out    => open,
        channel_out    => open, --channel_xadc
        eoc_out        => eoc_xadc,
        eos_out        => open,
        alarm_out    => open,
        vp_in        => xadc_p,
        vn_in        => xadc_n);
	
vgaRed <= (others => '0') when vga_rect = '0' else (others => '0');
vgaGreen <= (others => '0') when vga_rect = '0' else (others => '1');
vgaBlue <= (others => '0') when vga_rect = '0' else (others => '0');





process begin
    
 --   value <= do_xadc(15 downto 4);
    
	wait until rising_edge(clk25);
	
	if to_integer(unsigned(do_xadc(15 downto 4))) > 32  then
	   bool_move <= '1';
	else
	   bool_move <= '0';
	end if;
	
    if (frame = '1') then
        if (int_move < 640) and (bool_move = '0') then
            int_move <= int_move + 1;
        else
        if (int_move < 640) and (bool_move = '1') then
            int_move <= int_move - 1;
        else
            int_move <= 0;
        end if;
        end if;
    else
    end if;
	
	vga_visible_h <= '0';
	vga_visible_v <= '0';

	if to_integer(unsigned(hc_v)) > 146 and to_integer(unsigned(hc_v)) < 786 then
		screen_h <= to_integer(unsigned(hc_v)) - 146;
		vga_visible_h <= '1';
	else
		screen_h <= 0;
	end if;

	if to_integer(unsigned(vc_v)) > 34 and to_integer(unsigned(vc_v)) < 515 then
		screen_v <= 514 - to_integer(unsigned(vc_v));
		vga_visible_v <= '1';
	else
		screen_v <= 0;
	end if;
	
	vga_rect <= '0';
	if (screen_h > int_move) and (screen_h < int_move + 25) then
		vga_rect <= '1';
	end if;
	
end process;

end Behavioral;
